@@ -1,13 +1,16 @@
 # -*- coding: utf-8 -*-
-"""
-    Dealer
-    ======
 
-    Dealer tools for watching SCM.
+""" description.
+
+Dealer
+======
+
+The module for watching SCM (git, hg, svn).
+Use it for control a static's versions.
 
 """
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 __project__ = __name__
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "BSD"
